@@ -7,10 +7,11 @@
 #   Chris Travers <chris.travers@gmail.com>  (current maintainer)
 #
 # COPYRIGHT
-#   Copyright (C) 2014  Chris Travers.  
-#   Copyright (C) 2009-2013 Ford & Mason Ltd.  
-#   Copyright (C) 2006-2007 Andrew Ford.  
-#   Portions Copyright (C) 1996-2006 Andy Wardley.  
+#   Copyright (C) 2020  Erik Huelsmann.
+#   Copyright (C) 2014  Chris Travers.
+#   Copyright (C) 2009-2013 Ford & Mason Ltd.
+#   Copyright (C) 2006-2007 Andrew Ford.
+#   Portions Copyright (C) 1996-2006 Andy Wardley.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
@@ -35,10 +36,11 @@ use File::Spec;                         # from PathTools
 use IO::File;                           # from IO
 use Readonly;
 use File::pushd;                        # temporary cwd changes
+use Capture::Tiny qw(capture);
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = "0.200.4";
+our $VERSION = "1.0.0";
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -78,9 +80,12 @@ our %FORMATTERS  = (
     pdf        => [ 'xelatex' ],
     'pdf(pdflatex)' => [ 'pdflatex' ],
     'pdf(xelatex)'  => [ 'xelatex' ],
+    'ps(xelatex)'  => [ 'xelatex', 'pdf2ps' ],
     'pdf(dvi)'      => [ 'latex', 'dvipdfm' ],
     'pdf(ps)'       => [ 'latex', 'dvips', 'ps2pdf' ],
     'ps(pdf)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(pdflatex)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(xelatex)'       => [ 'xelatex', 'pdf2ps' ],
 );
 
 
@@ -131,7 +136,9 @@ sub new {
     # specified it is taken from that, or the default is take.
 
     my $output = $options->{output};
-    my $format = lc($options->{format});
+    my $format;
+    $format = lc($options->{format})
+        if $options->{format};
 
     if ($output and (!ref $output)) {
         my ($volume, $dir, $file) = File::Spec->splitpath($output);
@@ -215,6 +222,9 @@ sub new {
     my $texinputs_path = $options->{TEXINPUTS} || $options->{texinputs} || [];
     $texinputs_path = [ split(/:/, $texinputs_path) ] unless ref $texinputs_path;
 
+    # see http://tex.stackexchange.com/questions/149714/149865#149865
+
+    my $texinputs_sep = $OSNAME eq "MSWin32" ? ';' : ':';
 
 
     # construct and return the object
@@ -232,7 +242,7 @@ sub new {
                                  capture_stderr => $options->{capture_stderr} || 0,
                                  formatter      => $formatter,
                                  _program_path  => $path,
-                                 texinputs_path => join(':', ('.', @{$texinputs_path}, '')),
+                                 texinputs_path => join($texinputs_sep, ('.', @{$texinputs_path}, '')),
                                  preprocessors  => [],
                                  postprocessors => \@postprocessors,
                                  stats          => { runs => {} } } );
@@ -665,6 +675,7 @@ sub run_command {
 
     $envvars ||= "TEXINPUTS";
     $envvars = [ $envvars ] unless ref $envvars;
+    local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
     $self->stats->{runs}{$progname}++;
     debug("running '$program $args'") if $DEBUG;
     my $cwd = pushd($dir);
@@ -672,16 +683,28 @@ sub run_command {
     # Format the command appropriately for our O/S
 
     my $exit_status;
+    my $exit_error;
+    my ($stdout, $stderr);
     if ($OSNAME eq 'MSWin32') {
         $args = join(' ', @$args);
         $cmd  = "\"$program\" $args";
-        $exit_status = system($cmd);
+        ($stdout, $stderr) = capture {
+            $exit_status = system($cmd);
+            $exit_error = "$!";
+        };
     }
     else {
-        local(@ENV{@{$envvars}}) = map { $self->texinputs_path } @{$envvars};
         $args = "'$args'" if $args =~ / \\ /mx;
-        $exit_status = system($program, @$args);
+        ($stdout, $stderr) = capture {
+            $exit_status = system($program, @$args);
+            $exit_error = "$!";
+        };
     }
+    if ($exit_status == -1) {
+        $self->throw( "Failure to start $program: $exit_error" );
+    }
+    $self->{stderr} .= $stderr
+        if $self->{capture_stderr};
 
     return $exit_status;
 }
@@ -820,7 +843,7 @@ LaTeX::Driver - Latex driver
 
 =head1 VERSION
 
-This document describes version 0.200.4 of C<LaTeX::Driver>.
+1.0.0
 
 =head1 SYNOPSIS
 
